@@ -20,7 +20,11 @@ RECORDING_PATH=$DIRECTORY/screen_recording
 
 (rm -rf "$RECORDING_PATH" &> /dev/null || true)
 
-asciinema rec -c "$DIRECTORY/recorded_screen_script.sh" "$RECORDING_PATH"
+asciinema rec \
+  --command "$DIRECTORY/recorded_screen_script.sh" \
+  --cols 70 \
+  --rows 17 \
+  "$RECORDING_PATH"
 sed "s@$TEMP_DIR@~@g" "$RECORDING_PATH" | \
   svg-term \
     --window \
